import PageTransitionEffect from "@/components/PageTransitionEffect";
import clsx from "clsx";
import { Viewport } from "next";
import { NextIntlClientProvider } from "next-intl";
import { getMessages } from "next-intl/server";
import { Inter as FontSans } from "next/font/google";
import { ReactNode } from "react";
import "../globals.css";
import { Providers } from "./providers";
// 加载字体
const fontSans = FontSans({
    subsets: ["latin"],
    variable: "--font-sans",
});
export const viewport: Viewport = {
    themeColor: [
        { media: "(prefers-color-scheme: light)", color: "white" },
        { media: "(prefers-color-scheme: dark)", color: "black" },
    ],
};
export default async function LocaleLayout({
    children,
    params: { locale },
}: {
    children: ReactNode;
    params: { locale: string };
}) {
    const messages = await getMessages();
    return (
        <html lang={locale} suppressHydrationWarning style={{ fontSize: "12px" }}>
            <body className={clsx("font-sans", fontSans.variable)}>
                <NextIntlClientProvider messages={messages}>
                    <Providers themeProps={{ defaultTheme: "dark", attribute: "class" }}>
                        <PageTransitionEffect>
                            <main className={"h-[100vh]"}>{children}</main>
                        </PageTransitionEffect>
                    </Providers>
                </NextIntlClientProvider>
            </body>
        </html>
    );
}
